@@ -145,8 +145,13 @@ class Connector(object):
                               "%s", retry_exc.message)
                     raise
             else:
-                LOG.error("Authentication error detected. Cannot proceed: "
-                          "%s", e.message)
+                if method == 'GET' and url.endswith('SessionService'):
+                    LOG.debug('HTTP GET of SessionService failed %s, '
+                              'this is expected prior to authentication',
+                              e.message)
+                else:
+                    LOG.error("Authentication error detected. Cannot proceed: "
+                              "%s", e.message)
                 raise
         except exceptions.ServerSideError as e:
             if method.lower() != 'get' or server_side_retries <= 0:
